@@ -22,15 +22,14 @@ expect_error(idig_search_records(rq=list("asdf"="asdf")),
              "HTTP failure: 400")
 
 ## for idig_field_indexes
-context("test idig_field_indexes")
-v <- c("a", "data.b")
-l <- idig_field_indexes(v)
-expect_that(l[["a"]], is_equivalent_to(c("indexTerms", "a")))
-expect_that(l[["data.b"]], is_equivalent_to(c("data", "b")))
-v <- c("a", "geopoint", "flags", "recordids", "mediarecords")
-l <- idig_field_indexes(v)
-expect_that(l[["geopoint.lat"]], is_equivalent_to(c("indexTerms", "geopoint.lat")))
-expect_that(l[["geopoint.lon"]], is_equivalent_to(c("indexTerms", "geopoint.lon")))
-expect_that(is.null(l[["flags"]]), is_true())
-expect_that(is.null(l[["recordids"]]), is_true())
-expect_that(is.null(l[["mediarecords"]]), is_true())
\ No newline at end of file
+#context("test idig_field_indexes")
+#v <- c("a", "data.b")
+#l <- idig_field_indexes(v)
+#expect_that(l[["a"]], is_equivalent_to(c("indexTerms", "a")))
+#expect_that(l[["data.b"]], is_equivalent_to(c("data", "b")))
+#v <- c("a", "geopoint", "flags", "recordids", "mediarecords")
+#l <- idig_field_indexes(v)
+#expect_that(l[["geopoint.lat"]], is_equivalent_to(c("indexTerms", "geopoint.lat")))
+#expect_that(is.null(l[["flags"]]), is_true())
+#expect_that(is.null(l[["recordids"]]), is_true())
+#expect_that(is.null(l[["mediarecords"]]), is_true())
\ No newline at end of file
